import { Page } from "@/data/page";
import pageDtoTransformer, { PageDTO } from "@/api/dto/page";
import { axios } from "@/api";
import { STATIC_PAGE_ENDPOINT } from "@/api/page";
import { prepare } from "@/routing";
import { encapsulate, OneOrMany } from "@/helpers";

const STATIC_PAGE_INDEX_ENDPOINT = "/staticPage";

export { get, STATIC_PAGE_ENDPOINT } from "@/api/page"

export async function all(): Promise<Page[]> {
    const response = await axios.get<PageDTO[]>(STATIC_PAGE_INDEX_ENDPOINT);
    return response.data.map(dto => pageDtoTransformer.transform(dto));
}

export async function remove(page: OneOrMany<Pick<Page, "slug">>): Promise<void> {
    const pages = encapsulate(page);

    await Promise.all(pages.map(page => axios.delete(prepare(STATIC_PAGE_ENDPOINT, { slug: page.slug }))));
}

export async function save(page: Page): Promise<Page> {
    const response = await axios.put<PageDTO>(
        STATIC_PAGE_INDEX_ENDPOINT,
        pageDtoTransformer.reverseTransform(page),
    );

    return pageDtoTransformer.transform(response.data);
}
